docs.rs failed to build fcrypt-oqs-0.11.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Pinned Rust bindings to Open-Quantum-Safe's liboqs
This crate is the fcrypt project's API-compatible fork of tectonic-oqs.
It provides convenience wrappers around liboqs. For the FFI layer and the
verified C-source pin, see fcrypt-oqs-sys.
Features
std: (default) build withstdsupport. This adds handlyDisplayandErrorimplementations to relevant types. If you want a#![no_std]library, disable this feature (and you probably want to disable the default features because they pull in OpenSSL throughoqs-sys).non_portable: Don't build a portable library.vendored: (default) Controls thefcrypt-oqs-sys/vendoredfeature, which downloads, verifies, and builds the pinned liboqs source.kems(default): Compile with all KEMs enabledbike(only on non-Windows)classic_mceliecefrodokemhqckyberml_kemntruprime
sigs(default): Compile with all signature schemes enabledcrossdilithiumfalconmayoml_dsasphincs: SPHINCS+uov